@@ -5,38 +5,37 @@
 //! but they are undocumented, may change over time, and are generally more
 //! cumbersome to use.
 
+use borsh::BorshDeserialize;
+use futures::{future::join_all, Future, FutureExt};
 pub use solana_banks_interface::{BanksClient as TarpcClient, TransactionStatus};
-use {
-    borsh::BorshDeserialize,
-    futures::{future::join_all, Future, FutureExt},
-    solana_banks_interface::{BanksRequest, BanksResponse},
-    solana_program::{
-        clock::{Clock, Slot},
-        fee_calculator::FeeCalculator,
-        hash::Hash,
-        program_pack::Pack,
-        pubkey::Pubkey,
-        rent::Rent,
-        sysvar::{self, Sysvar},
-    },
-    solana_sdk::{
-        account::{from_account, Account},
-        commitment_config::CommitmentLevel,
-        signature::Signature,
-        transaction::{self, Transaction},
-        transport,
-    },
-    std::io::{self, Error, ErrorKind},
-    tarpc::{
-        client::{self, channel::RequestDispatch, NewClient},
-        context::{self, Context},
-        rpc::{ClientMessage, Response},
-        serde_transport::tcp,
-        Transport,
-    },
-    tokio::{net::ToSocketAddrs, time::Duration},
-    tokio_serde::formats::Bincode,
+use solana_banks_interface::{BanksRequest, BanksResponse};
+use solana_program::{
+    clock::Clock,
+    clock::Slot,
+    fee_calculator::FeeCalculator,
+    hash::Hash,
+    program_pack::Pack,
+    pubkey::Pubkey,
+    rent::Rent,
+    sysvar::{self, Sysvar},
 };
+use solana_sdk::{
+    account::{from_account, Account},
+    commitment_config::CommitmentLevel,
+    signature::Signature,
+    transaction::{self, Transaction},
+    transport,
+};
+use std::io::{self, Error, ErrorKind};
+use tarpc::{
+    client::{self, channel::RequestDispatch, NewClient},
+    context::{self, Context},
+    rpc::{ClientMessage, Response},
+    serde_transport::tcp,
+    Transport,
+};
+use tokio::{net::ToSocketAddrs, time::Duration};
+use tokio_serde::formats::Bincode;
 
 // This exists only for backward compatibility
 pub trait BanksClientExt {}
@@ -349,18 +348,16 @@ pub async fn start_tcp_client<T: ToSocketAddrs>(addr: T) -> io::Result<BanksClie
 
 #[cfg(test)]
 mod tests {
-    use {
-        super::*,
-        solana_banks_server::banks_server::start_local_server,
-        solana_runtime::{
-            bank::Bank, bank_forks::BankForks, commitment::BlockCommitmentCache,
-            genesis_utils::create_genesis_config,
-        },
-        solana_sdk::{message::Message, signature::Signer, system_instruction},
-        std::sync::{Arc, RwLock},
-        tarpc::transport,
-        tokio::{runtime::Runtime, time::sleep},
+    use super::*;
+    use solana_banks_server::banks_server::start_local_server;
+    use solana_runtime::{
+        bank::Bank, bank_forks::BankForks, commitment::BlockCommitmentCache,
+        genesis_utils::create_genesis_config,
     };
+    use solana_sdk::{message::Message, signature::Signer, system_instruction};
+    use std::sync::{Arc, RwLock};
+    use tarpc::transport;
+    use tokio::{runtime::Runtime, time::sleep};
 
     #[test]
     fn test_banks_client_new() {
